FAQ
----

* Do I need a supercomputing cluster to run this code?
    Not necessarily. Computing Kp--Vsys maps at the correct resolution and over the correct range will likely take ~15 hours on a laptop, though.
